# Chat Data Webhook Module for PrestaShop

This PrestaShop module sends webhook notifications whenever products are created, updated, or deleted in your store to the Chat Data platform. This integration allows your Chat Data chatbots to stay in sync with your product catalog in real-time.

## Features

- Sends webhook notifications for product events:
  - Product creation
  - Product updates
  - Product deletion
- Configurable webhook URL
- Secure webhook verification with signature
- Comprehensive product data in webhook payloads
- Test webhook functionality
- Works with PrestaShop 1.7 and 8.x

## Installation

1. Download the module ZIP file
2. Go to your PrestaShop back office
3. Navigate to Modules > Module Manager
4. Click "Upload a module" and select the ZIP file
5. After installation, configure the module by setting your webhook URL from Chat Data

## Configuration

1. Go to Modules > Module Manager
2. Find "Chat Data Webhook" and click "Configure"
3. Enter your webhook URL from Chat Data where notifications should be sent
4. Save the configuration

For detailed instructions, visit our [documentation page](https://cookbook.chat-data.com/docs/chatbots-real-time-products-update#prestashop-webhook-synchronization-integration).

## Testing Webhooks

After configuring your webhook URL, you can use the test feature to send a sample webhook:

1. On the module configuration page, scroll down to the "Test Webhook" section
2. Enter a valid product ID from your catalog
3. Select the event type you want to test (created, updated, or deleted)
4. Click "Send Test Webhook"
5. The system will display the result of the test webhook attempt

## Webhook Format

The webhooks are sent as JSON payloads with the following structure:

```json
{
  "event_type": "product.created|product.updated|product.deleted",
  "timestamp": "2023-08-01T12:34:56+00:00",
  "shop_url": "https://your-shop.com",
  "data": {
    "id": 123,
    "reference": "PROD123",
    "active": true,
    "price": "$99.99",
    "price_raw": 99.99,
    "quantity": 50,
    "categories": [2, 5],
    "name_default": "Product Name",
    "description_default": "Product description...",
    "description_short_default": "Short description...",
    "url": "https://your-shop.com/product-name",
    "images": ["https://your-shop.com/img/p/1/2/3.jpg"]
    // ...and more product data
  }
}
```

## Webhook Verification

Each webhook request includes a `X-PrestaShop-Webhook-Signature` header that can be used to verify the webhook's authenticity. The signature is a HMAC SHA-256 hash of the JSON payload, using the secret key displayed in the module configuration.

## Support

For any issues or questions, please contact Chat Data support or visit:
- Website: [https://www.chat-data.com](https://www.chat-data.com)
- Documentation: [https://cookbook.chat-data.com/docs/chatbots-real-time-products-update#prestashop-webhook-synchronization-integration](https://cookbook.chat-data.com/docs/chatbots-real-time-products-update#prestashop-webhook-synchronization-integration)

## License

This module is distributed under the terms of a commercial license.

## Author

Developed by Yongrui Su for Chat Data. 